@@ -24,6 +24,7 @@ from yaml.parser import ParserError  # noqa
 from yaml.scanner import ScannerError  # noqa
 
 from polyaxon.config_reader.utils import deep_update
+from polyaxon.env_vars.keys import POLYAXON_KEYS_PUBLIC_REGISTRY
 from polyaxon.exceptions import PolyaxonSchemaError
 from polyaxon.utils.list_utils import to_list
 
@@ -78,6 +79,9 @@ class ConfigSpec(object):
         if self.config_type == "url":
             return _read_from_url(self.value)
 
+        if self.config_type == "hub":
+            return _read_from_public_hub(self.value)
+
         raise PolyaxonSchemaError(
             "Received an invalid configuration: `{}`".format(self.value)
         )
@@ -117,7 +121,28 @@ def _read_from_url(url: str):
 
     resp = safe_request(url)
     resp.raise_for_status()
-    return _read_from_stream(resp.content)
+    return _read_from_stream(resp.content.decode())
+
+
+def get_default_registry():
+    return os.environ.get(
+        POLYAXON_KEYS_PUBLIC_REGISTRY,
+        "https://raw.githubusercontent.com/polyaxon/polyaxon-hub/dev",
+    )
+
+
+def _read_from_public_hub(hub: str):
+    hub_values = hub.split(":")
+    if len(hub_values) > 2:
+        raise PolyaxonSchemaError("Received an invalid hub reference: `{}`".format(hub))
+    if len(hub_values) == 2:
+        hub, version = hub_values
+    else:
+        hub, version = hub_values[0], "latest"
+    version = version or "latest"
+    registry = get_default_registry()
+    url = "{}/{}/{}.yaml".format(registry, hub, version)
+    return _read_from_url(url)
 
 
 def _read_from_stream(stream):
