@@ -27,6 +27,7 @@ from polyaxon.schemas.fields.params import PARAM_REGEX
 
 INPUTS = "inputs"
 OUTPUTS = "outputs"
+INPUTS_OUTPUTS = "io"
 ARTIFACTS = "artifacts"
 EVENTS = "events"
 STATUS = "status"
@@ -38,6 +39,7 @@ ITERATION = "iteration"
 CONTEXTS = {
     INPUTS,
     OUTPUTS,
+    INPUTS_OUTPUTS,
     ARTIFACTS,
     EVENTS,
     STATUS,
@@ -99,6 +101,7 @@ class ParamSchema(BaseCamelSchema):
     value = fields.Raw(required=True)
     search = fields.Nested(ParamSearchSchema, allow_none=True)
     ref = fields.Str(allow_none=True)
+    context_only = fields.Bool(allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -114,11 +117,155 @@ class ParamSchema(BaseCamelSchema):
 
 
 class V1Param(BaseConfig, polyaxon_sdk.V1Param):
+    """Params can provide values to inputs/outputs.
+
+    Params can be passed in several ways
+        * literal values that the user sets manually.
+        * a reference from a previous run, in which case
+          Polyaxon will validate during the compilation time if the user who initiated the run
+          has access to that organization/project/run.
+        * a reference from an upstream operation in the context of a DAG.
+        * a search, in which case the param will be a list of values based on the results
+          from executing the search.
+
+
+    When a param is passed from the CLI or directly in the YAML/Python specification,
+    it will be validated against the [inputs / outputs](/docs/core/specification/io/)
+    defined in the [component](/docs/core/specification/component/)
+
+    Args:
+         * value: any
+         * search: V1SearchParam, optional
+         * ref: str, optional
+         * context_only: bool, optional
+
+    ## YAML usage
+
+    ```yaml
+    >>> params:
+    >>>   loss:
+    >>>     value: MeanSquaredError
+    >>>   preprocess
+    >>>     value: true
+    >>>   accuracy
+    >>>     value: 0.1
+    >>>   outputs-path
+    >>>     ref: ops.upstream-job1
+    >>>     value: outputs.images-path
+    ```
+
+    ## Python usage
+
+    ```python
+    >>> from polyaxon.polyflow import V1Param
+    >>> params = {
+    >>>     "loss": V1Param(value="MeanSquaredError"),
+    >>>     "preprocess": V1Param(value=True),
+    >>>     "accuracy": V1Param(value=0.1),
+    >>>     "outputs-path": V1Param(ref="ops.upstream-job1", value="outputs.images-path")
+    >>> }
+    ```
+
+    ## Fields
+
+    ### value
+
+    The value to pass, if no `ref` or `search` is passed then it corresponds to a literal value,
+    and will be validated eagerly.
+    Otherwise it will be a future validation during the compilation time.
+
+    ```yaml
+    >>> params:
+    >>>   loss:
+    >>>     value: MeanSquaredError
+    ```
+
+    The value could be coming from the [context](/docs/core/specification/context/), for example:
+
+    ```yaml
+    >>> params:
+    >>>   current-project:
+    >>>     value: {{project_name}}
+    >>>   current-run:
+    >>>     value: {{uuid}}
+    ```
+
+    ### ref
+
+    Ref corresponds to a reference of an object.
+
+    A reference could be a previous run in the database or
+    an operation in DAG that has not been run yet.
+
+    ```yaml
+    >>> params:
+    >>>   loss:
+    >>>     value: outputs.loss
+    >>>     ref: ops.upstream-job-1
+    ```
+
+    ```yaml
+    >>> params:
+    >>>   loss:
+    >>>     value: outputs.loss
+    >>>     ref: runs.fcc462d764104eb698d3cca509f34154
+    ```
+
+    ### search
+
+    A Search corresponds to a valid search that can be resolved by Polyaxon,
+    the result will be inject to resolve the param value.
+
+    ```yaml
+    >>> params:
+    >>>   paths:
+    >>>     value: outputs.artifacts
+    >>>     search: {query: "metrics.loss: <0.01", sort: "metrics.loss", limit: 5}
+    ```
+
+    ```python
+    >>> params = {
+    >>>     "paths": V1Param(
+    >>>         value="outputs.artifacts",
+    >>>         search=V1ParamSearch(query="metrics.loss: <0.01", sort="metrics.loss", limit=5),
+    >>>     )
+    >>> }
+    ```
+
+    This will expose the artifacts generated by
+    the top 5 runs where the loss is less than 0.01 ascending.
+
+    ### contextOnly
+
+    A flag to signal to Polyaxon that this param should not be validated against inputs / outputs,
+    and it's only used to resolve some information and inject it to the context.
+
+    ```yaml
+    >>> params:
+    >>>   convolutions:
+    >>>     contextOnly: true
+    >>>     value:
+    >>>       conv1:
+    >>>          kernels: [32, 32]
+    >>>          size: [2, 2]
+    >>>          strides: [1, 1]
+    >>>       conv2:
+    >>>          kernels: [64, 64]
+    >>>          size: [2, 2]
+    >>>          strides: [1, 1]
+    ```
+
+    Polyaxon will not check if this param was required by an input / output,
+    and will inject it automatically in the context to be used.
+    You can use for example `{{ convolutions.conv1 }}` in the specification.
+    """
+
     SCHEMA = ParamSchema
     IDENTIFIER = "param"
     REDUCED_ATTRIBUTES = [
         "search",
         "ref",
+        "contextOnly",
     ]
 
     def validate(self):
