@@ -79,7 +79,7 @@ class TestPytorchJobCRD(BaseKubeflowCRDTestCase):
             restart_policy="never",
         )
         notifications = [
-            V1Notification(connection="test", trigger=V1NotificationTrigger.DONE)
+            V1Notification(connections=["test"], trigger=V1NotificationTrigger.DONE)
         ]
         master, master_replica_template = self.get_replica(environment)
         worker, worker_replica_template = self.get_replica(environment)
@@ -97,7 +97,7 @@ class TestPytorchJobCRD(BaseKubeflowCRDTestCase):
             },
             "collectLogs": True,
             "syncStatuses": True,
-            "notifications": [n.to_operator_notation() for n in notifications],
+            "notifications": [n.to_dict() for n in notifications],
         }
 
         expected_crd = get_custom_object(
