@@ -13,13 +13,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import numpy as np
 import os
+import pandas as pd
 import tempfile
 import uuid
 
 from unittest.mock import patch
 
+import altair as alt
 import matplotlib.pyplot as plt
 import pytest
 
@@ -46,7 +49,7 @@ from polyaxon.polyboard.artifacts import V1ArtifactKind
 from polyaxon.polyboard.events import V1Events, get_asset_path, get_event_path
 from polyaxon.tracking.events import EventFileWriter
 from polyaxon.tracking.events.writer import ResourceFileWriter
-from polyaxon.tracking.run import Run
+from polyaxon.tracking.run import TEMP_RUN_ARTIFACTS, Run
 from polyaxon.utils.path_utils import create_path
 
 
@@ -165,19 +168,19 @@ class TestRunTracking(TestEnvVarsCase):
         settings.CLIENT_CONFIG.is_managed = False
 
         run = Run(project="owner-test.test")
-        assert run.artifacts_path is None
-        assert run.outputs_path is None
+        assert run.get_artifacts_path() == TEMP_RUN_ARTIFACTS
+        assert run.get_outputs_path() == TEMP_RUN_ARTIFACTS
         assert run._event_logger is None
 
         # Add run id
         run = Run(project="owner-test.test", run_uuid="uuid")
-        assert run.artifacts_path is None
-        assert run.outputs_path is None
+        assert run.get_artifacts_path() == TEMP_RUN_ARTIFACTS
+        assert run.get_outputs_path() == TEMP_RUN_ARTIFACTS
         assert run._event_logger is None
 
         run.set_artifacts_path()
-        assert run.artifacts_path == CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("uuid")
-        assert run.outputs_path == CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("uuid")
+        assert run.get_artifacts_path() == CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("uuid")
+        assert run.get_outputs_path() == CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("uuid")
 
         with patch("polyaxon.tracking.run.EventFileWriter") as mock_call:
             run.set_run_event_logger()
@@ -193,8 +196,8 @@ class TestRunTracking(TestEnvVarsCase):
                 run = Run(project="owner-test.test", run_uuid="uuid")
         assert event_call.call_count == 1
         assert resource_call.call_count == 1
-        assert run.artifacts_path == CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("uuid")
-        assert run.outputs_path == CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("uuid")
+        assert run.get_artifacts_path() == CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("uuid")
+        assert run.get_outputs_path() == CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("uuid")
 
     def test_event_logger_from_a_managed_run(self):
         # Set managed flag
@@ -202,8 +205,8 @@ class TestRunTracking(TestEnvVarsCase):
         os.environ[POLYAXON_KEYS_RUN_INSTANCE] = "user.project_bar.runs.uid"
 
         run = Run()
-        assert run.artifacts_path == CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("uid")
-        assert run.outputs_path == CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("uid")
+        assert run.get_artifacts_path() == CONTEXT_MOUNT_ARTIFACTS_FORMAT.format("uid")
+        assert run.get_outputs_path() == CONTEXT_MOUNT_RUN_OUTPUTS_FORMAT.format("uid")
         assert run._event_logger is None
 
         # Set collect flag
@@ -263,7 +266,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.METRIC))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_metrics()
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -285,7 +288,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.METRIC))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_metrics(step=1, metric1=1.1)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -313,7 +316,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.METRIC))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_metrics(step=1, metric1=1.1, metric2=21.1)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -339,7 +342,7 @@ class TestRunLogging(TestEnvVarsCase):
         results = V1Events.read(kind="metric", name="metric2", data=events_file)
         assert len(results.df.values) == 1
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_metrics(step=2, metric1=1.1, metric2=21.1, metric3=12.1)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -381,7 +384,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         image_file = tempfile.mkdtemp() + "/file.png"
         self.touch(image_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_image(name="my_image", data=image_file)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -416,7 +419,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         image_file = tempfile.mkdtemp() + "/file.png"
         self.touch(image_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_image(name="my_image", data=image_file, step=1)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -449,7 +452,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.IMAGE))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_image(
                 name="my_image", data=tensor_np(shape=(1, 8, 8)), dataformats="CHW"
             )
@@ -486,7 +489,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         image_file = tempfile.mkdtemp() + "/file.png"
         self.touch(image_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_image_with_boxes(
                 name="my_image",
                 tensor_image=tensor_np(shape=(3, 32, 32)),
@@ -532,7 +535,7 @@ class TestRunLogging(TestEnvVarsCase):
         plt.axis("scaled")
         plt.tight_layout()
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_mpl_image(name="figure", data=figure, step=1, close=False)
         assert log_dashboard.call_count == 1
         assert plt.fignum_exists(figure.number) is True
@@ -558,7 +561,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         assert os.path.exists(asset_file) is True
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_mpl_image(name="figure", data=figure, step=2)
         assert log_dashboard.call_count == 1
         assert plt.fignum_exists(figure.number) is False
@@ -605,7 +608,7 @@ class TestRunLogging(TestEnvVarsCase):
             plt.tight_layout()
             figures.append(figure)
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_mpl_image(name="figure", data=figures, step=1, close=False)
         assert log_dashboard.call_count == 1
         assert all([plt.fignum_exists(figure.number) is True for figure in figures])
@@ -626,7 +629,7 @@ class TestRunLogging(TestEnvVarsCase):
         results = V1Events.read(kind="image", name="figure", data=events_file)
         assert len(results.df.values) == 1
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_mpl_image(name="figure", data=figures, step=2)
         assert log_dashboard.call_count == 1
         assert all([plt.fignum_exists(figure.number) is False for figure in figures])
@@ -671,7 +674,7 @@ class TestRunLogging(TestEnvVarsCase):
         plt.axis("scaled")
         plt.tight_layout()
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_mpl_plotly_chart(name="figure", figure=figure, step=1)
         assert log_dashboard.call_count == 1
 
@@ -691,7 +694,7 @@ class TestRunLogging(TestEnvVarsCase):
         results = V1Events.read(kind="image", name="figure", data=events_file)
         assert len(results.df.values) == 1
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_mpl_plotly_chart(name="figure", figure=figure, step=2)
         assert log_dashboard.call_count == 1
         assert plt.fignum_exists(figure.number) is False
@@ -723,7 +726,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         video_file = tempfile.mkdtemp() + "/video.gif"
         self.touch(video_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_video(name="my_video", data=video_file)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -756,7 +759,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.VIDEO))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_video(name="my_video", data=tensor_np(shape=(4, 3, 1, 8, 8)))
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -791,7 +794,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         audio_file = tempfile.mkdtemp() + "/audio.wav"
         self.touch(audio_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_audio(name="my_audio", data=audio_file)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -824,7 +827,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.AUDIO))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_audio(name="my_audio", data=tensor_np(shape=(42,)))
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -857,7 +860,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.TEXT))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_text(name="my_text", text="some text", step=1)
         assert log_dashboard.call_count == 1
 
@@ -886,7 +889,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.HTML))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_html(name="my_div", html="<div>test<div/>", step=1)
         assert log_dashboard.call_count == 1
         self.event_logger.flush()
@@ -914,7 +917,7 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.HISTOGRAM))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_histogram(
                 name="histo", values=tensor_np(shape=(1024,)), bins="auto", step=1
             )
@@ -951,7 +954,7 @@ class TestRunLogging(TestEnvVarsCase):
             is False
         )
         values, counts = np.histogram(np.random.randint(255, size=(1000,)))
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_np_histogram(
                 name="histo", values=values, counts=counts, step=1
             )
@@ -983,7 +986,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         model_file = tempfile.mkdtemp() + "model.pkl"
         self.touch(model_file)
-        with patch("polyaxon.tracking.run.Run._log_model") as log_model:
+        with patch("polyaxon.tracking.run.Run._log_has_model") as log_model:
             self.run.log_model(name="my_model", path=model_file, framework="scikit")
         assert log_model.call_count == 1
         self.event_logger.flush()
@@ -1024,7 +1027,7 @@ class TestRunLogging(TestEnvVarsCase):
         self.touch(weights_file)
         configs_file = model_dir + "/configs"
         self.touch(configs_file)
-        with patch("polyaxon.tracking.run.Run._log_model") as log_model:
+        with patch("polyaxon.tracking.run.Run._log_has_model") as log_model:
             self.run.log_model(name="my_model", path=model_dir, framework="tensorflow")
         assert log_model.call_count == 1
         self.event_logger.flush()
@@ -1059,7 +1062,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         model_file = tempfile.mkdtemp() + "/df.pkl"
         self.touch(model_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_dataframe(
                 name="dataframe", path=model_file, content_type="pickel"
             )
@@ -1096,7 +1099,7 @@ class TestRunLogging(TestEnvVarsCase):
         )
         tsv_file = tempfile.mkdtemp() + "/file.tsv"
         self.touch(tsv_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_artifact(
                 name="file", path=tsv_file, artifact_kind=V1ArtifactKind.TSV
             )
@@ -1141,14 +1144,14 @@ class TestRunLogging(TestEnvVarsCase):
         )
         tsv_file = tempfile.mkdtemp() + "/file.tsv"
         self.touch(tsv_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_artifact(
                 name="file", path=tsv_file, artifact_kind=V1ArtifactKind.TSV
             )
         assert log_dashboard.call_count == 1
         pd_file = tempfile.mkdtemp() + "/dataframe"
         self.touch(pd_file)
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_artifact(
                 name="file2", path=pd_file, artifact_kind=V1ArtifactKind.DATAFRAME
             )
@@ -1212,6 +1215,9 @@ class TestRunLogging(TestEnvVarsCase):
             hist_data, group_labels, bin_size=[0.1, 0.25, 0.5]
         )
 
+        df1 = pd.DataFrame([["A", "B", "C", "D"], [28, 55, 43, 91]], index=["a", "b"]).T
+        alt_test = alt.Chart(df1).mark_bar().encode(x="a", y="b")
+
         assert (
             os.path.exists(get_event_path(self.run_path, kind=V1ArtifactKind.CHART))
             is False
@@ -1220,10 +1226,11 @@ class TestRunLogging(TestEnvVarsCase):
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.CHART))
             is False
         )
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_bokeh_chart(name="bokeh_test", figure=bokeh_test, step=1)
             self.run.log_plotly_chart(name="plotly_test", figure=plotly_test, step=1)
-        assert log_dashboard.call_count == 2
+            self.run.log_altair_chart(name="alt_test", figure=alt_test, step=1)
+        assert log_dashboard.call_count == 3
         self.event_logger.flush()
         assert (
             os.path.exists(get_asset_path(self.run_path, kind=V1ArtifactKind.CHART))
@@ -1252,11 +1259,20 @@ class TestRunLogging(TestEnvVarsCase):
         )
         assert len(results.df.values) == 1
 
+        events_file = get_event_path(
+            self.run_path, kind=V1ArtifactKind.CHART, name="alt_test"
+        )
+        assert os.path.exists(events_file) is True
+        results = V1Events.read(
+            kind=V1ArtifactKind.CHART, name="alt_test", data=events_file
+        )
+        assert len(results.df.values) == 1
+
     def test_log_curves(self):
         x = [1, 2, 3, 4, 5]
         y = [6, 7, 2, 4, 5]
 
-        with patch("polyaxon.tracking.run.Run._log_dashboard") as log_dashboard:
+        with patch("polyaxon.tracking.run.Run._log_has_events") as log_dashboard:
             self.run.log_roc_auc_curve(name="roc_test", fpr=x, tpr=y, auc=0.6, step=1)
             self.run.log_pr_curve(
                 name="pr_test", precision=x, recall=y, average_precision=0.6, step=1
